The program needs to install
.Fn FEBUG_DEBUG_HANDLER
(or a wrapper around it) as the signal handler for
.Dv FEBUG_SIGNUM
(and any other signals, if different ones are explicitly requested); if notifications are disabled
.Pq by requesting Dv SIGKILL ,
some event loop that answers on
.Va FEBUG_GLOBAL_CONTROLLED_SOCKET
must be in place.
It's a no-op if
.Va FEBUG_GLOBAL_CONTROLLED_SOCKET
is
#ifndef FEBUG_GLOBAL_CONTROLLED_SOCKET_MINUS_ONE
#define FEBUG_GLOBAL_CONTROLLED_SOCKET_MINUS_ONE -1
#endif
.Sy FEBUG_GLOBAL_CONTROLLED_SOCKET_MINUS_ONE .
